from pysbd import Segmenter
from spacy.language import Language
from spacy.tokens import Doc


@Language.factory(
    "pysbd_sentencizer",
    assigns=["token.is_sent_start", "doc.sents"],
    default_config={},
)
def create_pysbd_sentencizer(nlp, name):
    return PySBDSentencizer(nlp, name)


class PySBDSentencizer(object):
    def __init__(self, nlp, name):
        self.name = name
        self.seg = Segmenter(language=nlp.lang, clean=False,
                             char_span=True)

    def __call__(self, doc: Doc):
        sents_char_spans = self.seg.segment(doc.text)
        start_token_ids = [sent.start for sent in sents_char_spans]
        for token in doc:
            token.is_sent_start = (True if token.idx in start_token_ids else False)
        if doc.has_annotation("SENT_START"):
            # Trim starting spaces
            for sent in doc.sents:
                sentlen = len(sent)
                first_non_space = 0
                while first_non_space < sentlen and sent[first_non_space].is_space:
                    first_non_space += 1
                if 0 < first_non_space < sentlen:
                    sent[0].is_sent_start = False
                    sent[first_non_space].is_sent_start = True
        return doc



import re
import sys
from pathlib import Path


def main(argv):
    part = argv[0].lower() if len(argv) > 0 else "minor"
    Jenkinsfile = Path("./Jenkinsfile")
    pyprojectfile = Path("./pyproject.toml")
    with Jenkinsfile.open("r", encoding="utf-8") as fin:
        data = fin.read()
        for line in data.split(fin.newlines):
            if "MAJOR_VERSION" in line:
                result = re.search(r'MAJOR_VERSION\s*=\s*"([0-9]+)"', line)
                if result:
                    major = int(result.group(1))
                    if part == "major":
                        to_replace = result.group(0)
                        by_replace = f"MAJOR_VERSION = \"{major + 1}\""
            if "MINOR_VERSION" in line:
                result = re.search(r'MINOR_VERSION\s*=\s*"([0-9]+)"', line)
                if result:
                    minor = int(result.group(1))
                    if part == "minor":
                        to_replace = result.group(0)
                        by_replace = f"MINOR_VERSION = \"{minor + 1}\""
    data = data.replace(to_replace, by_replace)
    with Jenkinsfile.open("wt") as fout:
        fout.write(data)

    depend_string = f"{major}.{minor}.0,<{major}.{minor + 1}.0"
    new_depend_string = f"{major}.{minor + 1}.0,<{major}.{minor + 2}.0"
    with pyprojectfile.open("r", encoding="utf-8") as fin:
        data = fin.read()
    data = data.replace(depend_string, new_depend_string)
    with pyprojectfile.open("wt") as fout:
        fout.write(data)


if __name__ == "__main__":
    main(sys.argv[1:])
